
  
  library(ggplot2) 
  library(gridExtra) 

 
  dat <- read.table("survey_data.csv", header = TRUE, sep = "," )
  names(dat) <- c("cadunico","areyouelig","whoiselig60","whoiselig120","who_toldyou","BF")

 
###### Table 1:  Program knowledge among the households targeted by the policy  ################################################### 

# set the table formatting
table <- data.frame(matrix(0,3,13))
table[,c(1,3,5,7,9,11)] <- "&" ; table[,c(13)] <- "\tabularnewline[0.25cm]"
row.names(table) <- c("BF Beneficiary","Non-Beneficiary","Observations")

### dummy that assumes 1 if household has BF benefit
dat$bf <- as.character(dat$BF) ; dat$bf[dat$BF == "Sim"] <- 1 ; dat$bf[dat$BF == "Nao"] <- 0

### dummy that assumes 1 if household knows about BF
dat$wastold <- 0 ; dat$wastold[!is.na(dat$who_toldyou)] <- 1 

### dummy that assumes 1 if household learned about BF from indirect source
dat$indirect <- 0 ; dat$indirect[dat$who_toldyou %in% c("Televisao/radio/jornal",
                                                           "Parentes","Vizinhos","Amigos")] <- 1
### dummy that assumes 1 if household enrolled in CadUnico
dat$enrolled[dat$cadunico == "Sim"] <- 1 ; dat$enrolled[dat$cadunico == "Nao"] <- 0

### dummy that assumes 1 if household claims to be BF eligible
dat$elig[dat$areyouelig == "Sim"] <- 1 ; dat$elig[dat$areyouelig == "Nao"] <- 0

### dummy that assumes 1 if household correctly identifies eligibility criteria
dat$a1[dat$whoiselig60 == "Sim"] <- 1 ; dat$a1[dat$whoiselig60 == "Nao"] <- 0
dat$a2[dat$whoiselig120 == "Sim"] <- 1 ; dat$a2[dat$whoiselig120 == "Nao"] <- 0
dat$knows_elig <- dat$a1 + dat$a2
dat$knows_elig[dat$knows_elig > 1] <- 1  
dat$a1 <- dat$a2 <- NULL

datx <- subset(dat, !is.na(BF) & !is.na(cadunico) )

# run regressions
for (i in 1:6){
  
  if(i ==1) {dat0 <- datx ; dat0$var <- dat0$wastold}
  if(i ==2) {dat0 <- subset(datx, wastold == 1 & !is.na(areyouelig) & !is.na(knows_elig)); dat0$var <- dat0$elig}
  if(i ==3) {dat0 <- subset(datx, wastold == 1 & !is.na(areyouelig) & !is.na(knows_elig)); dat0$var <- dat0$knows_elig}
  if(i ==4) {dat0 <- subset(datx, wastold == 1  & elig == 1 & !is.na(knows_elig)); dat0$var <- dat0$enrolled}
  if(i ==5) {dat0 <- subset(datx, wastold == 1  & elig == 1 & !is.na(knows_elig)); dat0$var <- dat0$indirect}
  if(i ==6) {dat0 <- subset(datx, wastold == 1  & elig == 1 & !is.na(knows_elig)); dat0$var <- abs(1-dat0$indirect)}
  
  
  test <- t.test(dat0$var[dat0$bf == 1],dat0$var[dat0$bf == 0])
  
  table[1,i*2] <- format(round(test$estimate[1]*100,1),nsmall=1)
  table[2,i*2] <- format(round(test$estimate[2]*100,1),nsmall=1)
  table[3,i*2] <- format(round(nrow(dat0),0),nsmall=0)
  
}

# print
table


###################################################################################################################################

###### Figure 2: Sources of BF information for poor households  ################################################################### 


#### select relevant variables
### dummy that assumes 1 if household has BF benefit
dat$bf <- as.character(dat$BF) ; dat$bf[dat$BF == "Sim"] <- 1 ; dat$bf[dat$BF == "Nao"] <- 0

### dummy that assumes 1 if household knows about BF
dat$wastold <- 0 ; dat$wastold[!is.na(dat$who_toldyou)] <- 1 

### dummy that assumes 1 if household learned about BF from indirect source
dat$indirect <- 0 ; dat$indirect[dat$who_toldyou %in% c("Televisao/radio/jornal",
                                                           "Parentes","Vizinhos","Amigos")] <- 1
### dummy that assumes 1 if household enrolled in CadUnico
dat$enrolled[dat$cadunico == "Sim"] <- 1 ; dat$enrolled[dat$cadunico == "Nao"] <- 0

### dummy that assumes 1 if household claims to be BF eligible
dat$elig[dat$areyouelig == "Sim"] <- 1 ; dat$elig[dat$areyouelig == "Nao"] <- 0

### dummy that assumes 1 if household correctly identifies eligibility criteria
dat$knows_elig[dat$whoiselig60 == "Sim" & dat$whoiselig120 == "Sim"] <- 1 
dat$knows_elig[dat$whoiselig60 == "Nao" & dat$whoiselig120 == "Nao"] <- 0

dat$wty <- "NA"
dat$wty[dat$who_toldyou %in% c("Televisao/radio/jornal")] <- "Media"
dat$wty[dat$who_toldyou %in% c("Parentes","Vizinhos","Amigos")] <- "Friends & Family"
dat$wty[dat$who_toldyou %in% c("Escola/creche")] <- "School"
dat$wty[dat$who_toldyou %in% c("Posto de saude/agentes comunitarios/ equipes de saude familiar","Na prefeitura","Secreteria ou equipamento da assistencia social (cras/creas/casa da familia)")] <- "Municipal Employees"

# run regressions
datx <- subset(dat, !is.na(who_toldyou) & !is.na(BF) & !is.na(dat$cadunico))
datx$c <- 1

for (i in 1:2){
  
  if(i == 1){forplot <- aggregate(c ~ wty + bf,dat=datx,sum)}else{forplot <- aggregate(c ~ wty + enrolled,dat=datx,sum)}
  forplot$pct <- forplot$c*100/sum(forplot$c)  
  names(forplot)[2] <- "g" ;     forplot$g <- as.factor(forplot$g)
  if(i == 1){nam <- "Receiving Bolsa Fam?lia?"}else{nam <- "Enrolled in CadUnico?"}
  
  p <- ggplot(dat=forplot, aes(x=wty, y=pct, group=g))   + 
    scale_x_discrete(labels=c("Friends and \n Family","Media","Municipal \n Employees","School")) +
    scale_fill_manual(values=c("gray25","gray75"), label=c("No","Yes"), name=nam)  +
    geom_bar(aes(x=wty, y=pct, group=g, fill=g),colour="black",stat="identity", position = "dodge") +
    xlab("Contact Source") + ylab("% Share of Total") +
    theme(axis.title.x = element_blank()) +
    theme(plot.title = element_blank()) +
    theme(axis.text = element_text(colour="black", size=10)) +
    theme(axis.title.y = element_text(colour="black", size=10)) +
    theme(legend.title = element_text(colour="black", size=10)) +
    theme(legend.position="bottom")
  
  if(i == 1){p1 <- p}else{p2 <- p}
}

# print
grid.arrange(p1, p2, nrow = 1, ncol=2  )




###################################################################################################################################


