

  
  ### Load teh following libraries
  library(rdd)
  library(rdrobust) 
  library(ggplot2) 
  library(gridExtra) 


  dat <- read.table("main_data.csv", header = TRUE, sep = "," )

  
  ### Please create these functions for the presentation of RD results
  weighting <- function(xx,kernel,cut){
    
    if(kernel > 0){
      if(kernel == 1){xx$wght <- cut - abs(xx$run)}
      if(kernel == 2){xx$wght <- 0.75*(1 - ((xx$run/cut)**2))}
      if(kernel == 3){xx$wght <- (1/((2*pi)**2))*exp(-0.5*((abs(xx$run/cut)**2)))}
      xx$wght[xx$t == 1] <- xx$wght[xx$t == 1] / sum(xx$wght[xx$t == 1])
      xx$wght[xx$t == 0] <- xx$wght[xx$t == 0] / sum(xx$wght[xx$t == 0])
    }else{xx$wght <- 1/nrow(xx)}
    return(xx)
  }
  RD <- function(data,Var,run,t,cut,band,bins,degree,x.title,y.title,title,con,sz,ymx,ymn) {
    
    if(degree == 1){mm <- (Var ~ Score2 )}
    if(degree == 2){mm <- (Var ~ Score2 + I(Score2**2) )}
    if(degree == 3){mm <- (Var ~ Score2 + I(Score2**2) + I(Score2**3) )}
    
    data <- data.frame(data)
    data$Var <- data[,match(Var,names(data))]
    data <- subset(data, !is.na(Var))
    data$run <- data[,match(run,names(data))]  
    data$t <- data[,match(t,names(data))] 
    
    data$Score2 <- data$run - cut 
    data <- subset(data, abs(Score2) <= band)
    vec <- seq(cut, band, length.out =  (bins+1))
    vec_mid <- vec[-length(vec)] + diff(vec)/2
    iii <- 0
 
    for (iii in 0:1){
      cc <- iii 
      if(iii == 0) cc <- -1
      aux <- subset(data, t == iii) ; aux$count <- 1
      aux$groups <- as.factor(cut(cc*aux$Score2,breaks=vec, include.lowest = TRUE))
      R <- aggregate(Var ~ groups,    data=aux, mean)
      R2 <- aggregate(count ~ groups, data=aux, sum)
      R <- merge(R,R2,by="groups")
      R$rank <- as.numeric(substring(R$groups,2,2))
      R <- R[order(R$groups),]
      
      #RR <- group_by(aux,groups) %>% summarise (Var = mean(Var), count = sum(count) ) #%>% complete(groups)
      #R <- subset(RR, !is.na(Var))
      R$t <- iii
      R$Score2 <- cc*vec_mid
      
      mdl <- lm(mm , data = aux) 
      pred <- predict(mdl, R, interval = "confidence", level = con, na.action = na.pass) 
      PRE <- pred[,1] ; R$pre <- PRE
      predSE <- predict(mdl, R, interval = "confidence", level =con, na.action = na.pass, se=TRUE)$se.fit
      t <- ((pred[1,1]-pred[1,2])/predSE[1])
      V <- as.matrix(vcov(mdl))  
      
      if(degree == 1){X <- data.frame(1,R$Score2)}
      if(degree == 2){X <- data.frame(1,R$Score2,(R$Score2^2))}
      if(degree == 3){X <- data.frame(1,R$Score2,(R$Score2^2),(R$Score2^3))}
      
      X <- as.matrix(X) ; se_robust <- sqrt(diag(X %*% V %*% t(X)))
      LOW <- pred[,1] - t*se_robust ; HIGH <- pred[,1] + t*se_robust
      R$low <- LOW ;    R$high <- HIGH 
      
      if(iii == 0){R0 <- R ; plot_data <- R}else{R1 <- R ;plot_data <- rbind(plot_data,R)}
    }
    
    plot_data <- data.frame(plot_data)
    plot_data <- subset(plot_data, !is.na(count))
    plot_data$count2 <- plot_data$count/sum(plot_data$count)
    ymx <- ymx
    ymn <- ymn
    
    ggplot(data=plot_data, aes(x=Score2, y=Var, ymax = ymx, ymin = ymn))   + 
      theme_bw() +
      geom_line(data=R0, aes(x=Score2, y=pre),colour="gray10",  size=0.75) +
      geom_line(data=R1, aes(x=Score2, y=pre),colour="gray10",  size=0.75) +
      geom_vline(xintercept = 0, colour="gray25", linetype = "longdash") +
      geom_point( data=plot_data,aes(size = count2/3), shape=16, color = "gray40", bg="gray40") +
      ggtitle(title) + 
      theme(plot.title = element_text(size=12))+
      xlab(x.title) + ylab(y.title) +
      theme(axis.text = element_text(colour="black", size=12)) +
      theme(axis.title = element_text(colour="black", size=12)) +
      geom_ribbon(data=R0, aes(ymin=low,ymax=high),alpha=0.10) +
      geom_ribbon(data=R1, aes(ymin=low,ymax=high),alpha=0.10) +
      theme(legend.position="none")
    
    
  }
 
  ### set the value of teh following variables
  dat$enroll <- dat$enter*100/dat$Target_CU10 
  dat$elig <- dat$eligible*100/(dat$enter)
  dat$newbf <- dat$bf12*100/(dat$enter)
  dat$yieldbf <- dat$bf12*100/(dat$eligible)
  dat$drop1 <-  (dat$bf13 - dat$bf12)*100/dat$eligible
  dat$drop2 <-  (dat$bf13 - dat$bf12)*100/dat$enter
  dat$past_entrants <- (dat$CU08/dat$Target_CU06)
  dat$run <- dat$MV ; dat$run[dat$t == 0] <- -dat$run[dat$t == 0] 
  dat$lsa <- log(dat$sa_emp)
  dat$pt <- 0 ; dat$pt[dat$Party == 13] <- 1
  dat$psdb <- 0 ; dat$psdb[dat$Party == 45] <- 1
  dat$pmdb <- 0 ; dat$pmdb[dat$Party == 15] <- 1
  dat$Left <- 0 ; dat$Left[dat$Party %in% c(12,13,16,20,23,29,40,50,54,65)] <- 1
  dat$Poverty_p <- dat$Target_BF06/(dat$hsd08)
  dat$cov_p2 <- dat$BF08/dat$Target_BF04
  
  ### vector of covariates
  vec_cov <-  c("Age","Sex","College","Occ_5","Occ_3","pt","pmdb","psdb","Left","Turnout","gini","gdppc","Poverty_p","cov_p2","lsa","h_visits")
  vec_cov1 <- c("Age","Sex","College","Occ_5","Occ_3","pt","pmdb","psdb","Left","Turnout","gini","gdppc","Poverty_p","cov_p2")
  
  
###### Table 2:  Reelection incentives lead to negative screening  ################################################################# 

  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the outcome variable
  base_exp$Var <- base_exp$drop1 

  # set the table formatting
  table <- data.frame(matrix(0,6,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,4,6),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (R. Incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # run regressions
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
   
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  
  # print
  table

###################################################################################################################################

###### Figure 3: BF screening at the discontinuity  ############################################################################### 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  #### select relevant variables
  ### dummy that assumes 1 if household has BF benefit
  base_exp$Var <- base_exp$drop1

  band <- 10
  bdx <- subset(base_exp, MV <= band & !is.na(Var) & abs(Var) != Inf )

  RD(bdx,"Var","run","t",0,band=10,bins=10,1,"Margin of Victory","Screening","",.95,sz=1,ymx=-3,ymn=-8)
  
 
###################################################################################################################################

###### Table 3:  Alternative explanations: expansion and management quality of BF in 2009-2012  #################################### 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the table formatting
  table <- data.frame(matrix(0,6,11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" ; table[c(3,4,6),11] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD Effect (R. incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # run regressions
  for (i in 1:5){
    
    # set the relevant outcomes
    if(i == 1) base_exp$Var <- base_exp$enroll 
    if(i == 2) base_exp$Var <- base_exp$elig 
    if(i == 3) base_exp$Var <- base_exp$newbf 
    if(i == 4) base_exp$Var <- base_exp$yieldbf 
    if(i == 5) base_exp$Var <- base_exp$Igd12
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf ) 
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri", b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[4,i*2] <- format(round(reg$tau_cl[1],3),nsmall=3)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[5,i*2] <- format(round(band[1],1),nsmall=1)
    table[6,i*2] <- format(round(nrow(bdxx),0),nsmall=0)
    
    
  }
  
  # print
  table
  
###################################################################################################################################  

###### Figure 4: Municipal bureaucracy and past CadUnico enrollment  ############################################################## 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  #### set number of quantiles
  n <- 10
  
  ### dummy that assumes 1 if household has BF benefit
  for (i in 1:2){
    
    if(i == 1){base_exp$vari <- (base_exp$h_visits)}else{base_exp$vari <- (base_exp$lsa)}
    bdx <- subset(base_exp, !is.na(vari) & vari > -Inf)
    
    ps <- 0:n/n
    se <- quantile(prob=ps, bdx$vari ) ;  se[1] <- se[1]-0.0001
    bdx$range <- cut(bdx$vari, se)
    bdx$count <- 1
    agg1 <- aggregate(past_entrants ~ range, data=bdx, mean)
    agg2 <- aggregate(vari ~ range, data=bdx, median)
    agg3 <- aggregate(count ~ range, data=bdx, sum)
    
    agg <- merge(agg1,agg2,by="range")
    agg <- merge(agg,agg3,by="range")
    agg$q <- 1:n
    
    p <-  ggplot(data=agg, aes(x=q, y=past_entrants))   + 
      theme_bw() +
      ylim(0.7,1.1) +
      geom_point(shape=16, size = 3, color = "steelblue2") +
      xlab("Quantile in Health Visits") + ylab("Registry Coverage") +
      theme(axis.text = element_text(colour="black", size=12)) +
      theme(axis.title = element_text(colour="black", size=12)) +
      scale_x_continuous(breaks=c(2.5,5,7.5,10),labels=c("25th","50th","75th","99th"))+
      stat_smooth(data=agg, aes(x=q, y=past_entrants), color="gray50", method = "loess", formula = y ~ x  , size = 1)
    
    if(i == 1){p1 <- p}else{p2 <- p}
    
  } 
  
  # print
  grid.arrange(p1, p2, nrow = 1, ncol=2  )
  
  
  
  
###################################################################################################################################
  
###### Table 4:  Heterogeneity of effects by the strength of the information channels  #################################### 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the table formatting
  table <- data.frame(matrix(0,5,7))
  table[,c(1,3,5)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,5),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD Effect (Reelection incentives)","S.E.","C.I.","Bandwidth ","Observations ")
  
  # set outcome variable
  base_exp$Var <- base_exp$drop1
  
  # set splitting variable
  base_exp$gap <- base_exp$lsa
  mat <- matrix(0,6,2) 

  # run regressions I
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & !is.na(gap)   )
  
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
   
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table1 <- table
  
  # set splitting variable
  base_exp$gap <- base_exp$h_visits
  mat <- matrix(0,6,2) 
  
  # run regressions II
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & !is.na(gap)   )
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table2 <- table
  
  # print
  print(table1) ; print(table2)

  
###################################################################################################################################  
  
###### Table 6:  Reelection incentives generate anomalous income reporting patterns  ############################################## 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the outcome variable
  base_exp$Var <- base_exp$close05*100 / base_exp$range05
  
  # set the table formatting
  table <- data.frame(matrix(0,6,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,4,6),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (R. Incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # run regressions
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  
  # print
  table
  
###################################################################################################################################  

  
  
############### Appendix  
  
###### Table A.I: RD effects for the inexperienced sample  ######################################################################## 
  
  # select only mayoral candidates in the inexperienced sample
  base_exp <- subset(dat, pref2000 == 0 ) 
  
  # set the outcome variable
  base_exp$Var <- base_exp$drop1 
  
  # set the table formatting
  table <- data.frame(matrix(0,6,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,4,6),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (Reelection Incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # run regressions
  for (i in 1:4){
    
    if(i == 1) base_exp$Var <- base_exp$drop1
    if(i == 2) base_exp$Var <- base_exp$enroll
    if(i == 3) base_exp$Var <- base_exp$elig
    if(i == 4) base_exp$Var <- base_exp$yieldbf
    
    pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  
  # print
  table
  
  
###################################################################################################################################
 
###### Table A.II: Balance of covariates in the inexperienced sample  ############################################################# 
  
  vec_cov_names <- c("Mayor's Age","Mayor's Gender","Mayor's Education",
                     "M. Background: Public Sector","M. Background: High-Skilled","Mayor's Party: PT","Mayor's Party: PMDB","Mayor's Party: PSDB",
                     "Mayor's Party: Left","Turnout, 2008","Gini Coefficient, 2000","Per Capita GDP, 2008",
                     "Poverty Rate, 2008","BF Coverage, 2008","SS Employees, 2009","Visits per Family, 2006-08")
  
  # select only mayoral candidates in the inexperienced sample
  base_exp <- subset(dat, pref2000 == 0 ) 
  bdd <- base_exp  
  
  table <- data.frame(matrix(0,length(vec_cov),11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  row.names(table) <- vec_cov_names
  
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  
  
  table 
  
  
  
###################################################################################################################################  
  
###### Table A.III: Differences between experienced and inexperienced control groups  ############################################# 
  
  vec_cov_names <- c("Mayor's Age","Mayor's Gender","Mayor's Education",
                     "M. Background: Public Sector","M. Background: High-Skilled","Mayor's Party: PT","Mayor's Party: PMDB","Mayor's Party: PSDB",
                     "Mayor's Party: Left","Turnout, 2008","Gini Coefficient, 2000","Per Capita GDP, 2008",
                     "Poverty Rate, 2008","BF Coverage, 2008","SS Employees, 2009","Visits per Family, 2006-08")
  
  # select only control groups
  bd <- subset(dat, t == 0 & pref2000 >= 0  )  
  bd$tt <- bd$t ; bd$t <- bd$pref2000 ; bd$run <- bd$MV*(2*bd$t-1)
  
  vec_cov2 <- c("drop1","drop2","enroll","elig","newbf","yieldbf","Igd12",vec_cov)
  
  table <- data.frame(matrix(0,length(vec_cov2),11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  row.names(table) <- c("Bf Drop 1, 2013","Bf Drop 2, 2013","New enrolled, 2013","Eligible share, 2012","New benefits, 2012",
                        "BF yield, 2012","IGD index, 2010",vec_cov_names)
  confi <- 95
  
  for (i in 1:length(vec_cov2)){
    
    bd$Var <- bd[,match(vec_cov2[i],names(bd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bd, !is.na(Var) & abs(Var) != Inf) 

    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
 
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  table  
  

  
###################################################################################################################################  
  
###### Table A.IV:  Covariate balance at the discontinuity  ########################################################### 
  
  vec_cov_names <- c("Mayor's Age","Mayor's Gender","Mayor's Education",
                     "M. Background: Public Sector","M. Background: High-Skilled","Mayor's Party: PT","Mayor's Party: PMDB","Mayor's Party: PSDB",
                     "Mayor's Party: Left","Turnout, 2008","Gini Coefficient, 2000","Per Capita GDP, 2008",
                     "Poverty Rate, 2008","BF Coverage, 2008","SS Employees, 2009","Visits per Family, 2006-08")
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  bdd <- base_exp  #> qqq

  table <- data.frame(matrix(0,length(vec_cov),11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  row.names(table) <- vec_cov_names
  
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  
  
  table 
  
 
  
###################################################################################################################################  
  
###### Table A.V:  Reelection incentives lead to negative screening (Robustness)  ################################################## 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 

  # set the table formatting
  table <- data.frame(matrix(0,5,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,5),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (R. Incentives)","S.E.","C.I.","Bandwidth ","Observations ")
  
  # set vector of covariates
  vec_cov1 <- c("Age","Sex","College","Occ_5","Occ_3","pt","pmdb","psdb","Left","Turnout","gini","gdppc","Poverty_p","cov_p2")
 
  # set variable and run regressions
  base_exp$Var <- base_exp$drop1 
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  )
    zet <- bdx[,vec_cov1]
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",covs=zet)$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1],covs=zet)
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table1 <- table
  
  # set variable and run regressions
  base_exp$Var <- base_exp$drop2 
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table2 <- table
  
  # print
  print(table1) ; print(table2)
  
###################################################################################################################################
  
###### Table A.VI:  Expansion and management quality of BF in 2009-2012 (Robustness)  ############################################# 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 

  # set vector of covariates
  vec_cov1 <- c("Age","Sex","College","Occ_5","Occ_3","pt","pmdb","psdb","Left","Turnout","gini","gdppc","Poverty_p","cov_p2")

  # set the table formatting
  table <- data.frame(matrix(0,6,11))
  table[,c(1,3,5,7)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" ; table[c(3,4,6),11] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD Effect (R. incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # run regressions (2nd degree polynomial)
  pp <- 2
  for (i in 1:5){
    
    # set the relevant outcomes
    if(i == 1) base_exp$Var <- base_exp$enroll 
    if(i == 2) base_exp$Var <- base_exp$elig 
    if(i == 3) base_exp$Var <- base_exp$newbf 
    if(i == 4) base_exp$Var <- base_exp$yieldbf 
    if(i == 5) base_exp$Var <- base_exp$Igd12
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=pp+1,bwselect="cerrd")$bws[c(1,3)]
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = pp+1,kernel = "tri", b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[4,i*2] <- format(round(reg$tau_cl[1],3),nsmall=3)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[5,i*2] <- format(round(band[1],1),nsmall=1)
    table[6,i*2] <- format(round(nrow(bdxx),0),nsmall=0)
    
    
  }
  table1 <- table
    
  # run regressions (3rd degree polynomial)
  pp <- 3
  for (i in 1:5){
    
    # set the relevant outcomes
    if(i == 1) base_exp$Var <- base_exp$enroll 
    if(i == 2) base_exp$Var <- base_exp$elig 
    if(i == 3) base_exp$Var <- base_exp$newbf 
    if(i == 4) base_exp$Var <- base_exp$yieldbf 
    if(i == 5) base_exp$Var <- base_exp$Igd12
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=pp+1,bwselect="cerrd")$bws[c(1,3)]
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = pp+1,kernel = "tri", b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[4,i*2] <- format(round(reg$tau_cl[1],3),nsmall=3)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[5,i*2] <- format(round(band[1],1),nsmall=1)
    table[6,i*2] <- format(round(nrow(bdxx),0),nsmall=0)
    
    
  }
  table2 <- table
  
  # set variable and run regressions
  pp <- 1
  for (i in 1:5){
    
    # set the relevant outcomes
    if(i == 1) base_exp$Var <- base_exp$enroll 
    if(i == 2) base_exp$Var <- base_exp$elig 
    if(i == 3) base_exp$Var <- base_exp$newbf 
    if(i == 4) base_exp$Var <- base_exp$yieldbf 
    if(i == 5) base_exp$Var <- base_exp$Igd12
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf ) 
    zet <- bdx[,vec_cov1]
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=pp+1,bwselect="cerrd",covs=zet)$bws[c(1,3)]
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = pp+1,kernel = "tri", b=band[2],h=band[1],covs=zet)
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[4,i*2] <- format(round(reg$tau_cl[1],3),nsmall=3)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[5,i*2] <- format(round(band[1],1),nsmall=1)
    table[6,i*2] <- format(round(nrow(bdxx),0),nsmall=0)
    
    
  }
  table3 <- table
  
  
  # print
  print(table1) ; print(table2) ; print(table3)
  
###################################################################################################################################
  
###### Table A.VII:  Heterogeneity of effects of reelection incentives by other variables  ######################################## 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the table formatting
  table <- data.frame(matrix(0,5,7))
  table[,c(1,3,5)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,5),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD Effect (Reelection incentives)","S.E.","C.I.","Bandwidth ","Observations ")
  
  # set outcome variable
  base_exp$Var <- base_exp$drop1
  
  # set splitting variable
  base_exp$gap <- base_exp$radio
  mat <- matrix(0,6,2) 
  
  # run regressions I
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & !is.na(gap)   )
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table1 <- table
  
  # set splitting variable
  base_exp$gap <- base_exp$Poverty_p
  mat <- matrix(0,6,2) 
  
  # run regressions II
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & !is.na(gap)   )
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table2 <- table
  
  # set splitting variable
  base_exp$gap <- base_exp$gini
  mat <- matrix(0,6,2) 
  
  # run regressions II
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & !is.na(gap)   )
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table3 <- table
  
  # print
  print(table1) ; print(table2) ; print(table3)
  
  

  
###################################################################################################################################  
  
###### Table A.VIII:  Anomalous income reporting patterns (Robustness)  ########################################################### 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set vector of covariates
  vec_cov1 <- c("Age","Sex","College","Occ_5","Occ_3","pt","pmdb","psdb","Left","Turnout","gini","gdppc","Poverty_p","cov_p2")
  
  # set the table formatting
  table <- data.frame(matrix(0,5,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,5),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (R. Incentives)","S.E.","C.I.","Bandwidth ","Observations ")
  
  # set variable and run regressions
  base_exp$Var <- base_exp$close05*100/ base_exp$range05
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  )
    zet <- bdx[,vec_cov1]
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",covs=zet)$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq, b=band[2],h=band[1],covs=zet)
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table1 <- table
  
  # set variable and run regressions
  base_exp$Var <- base_exp$close07*100/ base_exp$range07 
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table2 <- table
  
  # set variable and run regressions
  base_exp$Var <- base_exp$close10*100/ base_exp$range10
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table3 <- table  
  
  # set variable and run regressions
  base_exp$Var <- base_exp$range10*100/base_exp$enter
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),digits=3)
    table[5,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table4 <- table 
   
  # print
  print(table1) ; print(table2) ; print(table3) ; print(table4)
  
###################################################################################################################################
  
###### Table A.IX:  Anomalous income reporting patterns (Placebo Tests)  ########################################################## 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the table formatting
  table <- data.frame(matrix(0,6,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,4,6),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect (R. Incentives)","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
   # set variable and run regressions
  base_exp$Var <- base_exp$close_f_plus20*100/ base_exp$range_f_plus20 
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table1 <- table
  
  # set variable and run regressions
  base_exp$Var <- base_exp$close_f_minus20*100/ base_exp$range_f_minus20
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table2 <- table  
  
  # set variable and run regressions
  base_exp$Var <- base_exp$below_census*100
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table3 <- table 
  
  # print
  print(table1) ; print(table2) ; print(table3) 
  
###################################################################################################################################
 
###### Table A.X:  Heterogeneity of effects of reelection incentives effects by the past of the challenger  ####################### 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  # set the table formatting
  table <- data.frame(matrix(0,5,7))
  table[,c(1,3,5)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,5),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD Effect (Reelection incentives)","S.E.","C.I.","Bandwidth ","Observations ")
  
  # set outcome variable
  base_exp$Var <- base_exp$drop1
  
  # set splitting variable
  base_exp$past[base_exp$type == "limited"] <- 0
  base_exp$past[base_exp$type %in% c("lost","notrun")] <- 1
  base_exp$gap <- base_exp$past
  mat <- matrix(0,6,2) 
  
  summary(dat$type)
  
  # run regressions I
  for (i in 1:2){
    
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf & type %in% c("limited","notrun","lost")   )
    
    pp <- 1 ; qq <- 2
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd",scaleregul=1)$bws[c(1,3)]
    qqq <- quantile(prob=.50,bdx$gap, na.rm=TRUE)
    
    bdx$i <- 0
    if(i==1) {bdx$i[bdx$gap <= qqq] <- 1}else{bdx$i[bdx$gap > qqq] <- 1}
    
    bdx$irun <- bdx$i*bdx$run
    bdx$it <- bdx$i*bdx$t
    bdx$itrun <- bdx$i*bdx$t*bdx$run
    Z <- cbind(bdx$i,bdx$irun,bdx$it,bdx$itrun)
    
    bdxx <- subset(bdx, MV <= band[1]) ; bdxx <- weighting(bdxx,1,cut=band[1]) 
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = 1, q = 2,h=band[1],b=band[2], covs=Z)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    table[1,i*2] <- format(te,nsmall=3)
    table[2,i*2] <- paste("(",format(se,nsmall=3),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],nsmall=2),",",format(ci[2],nsmall=2),"]",sep="")
    table[4,i*2] <- format(round(band[1],1),nsmall=1)
    table[5,i*2] <- format(round(nrow(subset(bdxx,i==0)),0),nsmall=0)
    mat[1,i] <- reg$coef[3]
    mat[2,i] <- te ; mat[3,i] <- se 
    
    if(i==2){ newco <- round(mat[1,2] - mat[1,1] ,3)
    newse <- round(((mat[3,2]^2+mat[3,1]^2)^.5),3)
    table[1,6] <- format((mat[2,2]-mat[2,1]),nsmall=3)
    table[2,6] <- paste("(",format(newse,nsmall=3),")",sep="")
    table[3,6] <- paste("[",format(round(newco-1.96*newse,2),nsmall=2),",",format(round(newco+1.96*newse,2),nsmall=2),"]",sep="")
    table[4,6] <- table[4,4]
    table[5,6] <- format(round(nrow(bdxx),0),nsmall=0)
    }
  }
  table

  
  
###################################################################################################################################  
  
###### Table A.XI: Correlation between screening, enrollment and enforcement of eligibility criteria  ############################# 
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  base_exp$Var <- base_exp$drop1
  
   # set the table formatting
  table <- data.frame(matrix(0,6,9))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  table[c(3,4,6),ncol(table)] <- "\tabularnewline[0.25cm]"
  row.names(table) <- c("RD effect of high enrollment","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  # set variable and run regressions
  base_exp$inter <- base_exp$enroll
  base_exp$t <- 0
  base_exp$t[base_exp$inter > quantile(prob=0.50,base_exp$inter)] <- 1
  base_exp$run <- base_exp$MV*(2*base_exp$t-1)
  
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table1 <- table
  
  # set variable and run regressions
  row.names(table) <- c("RD effect of lax enforcement","S.E.","C.I.","Pre-treatment mean","Bandwidth ","Observations ")
  
  base_exp$inter <- base_exp$elig
  base_exp$t <- 0
  base_exp$t[base_exp$inter > quantile(prob=0.50,base_exp$inter)] <- 1
  base_exp$run <- base_exp$MV*(2*base_exp$t-1)
  
  for (i in 1:4){
    
    pp <- i
    if(i == 4) pp <- 1
    
    qq <- pp+1
    bdx <- subset(base_exp, !is.na(Var) & abs(Var) != Inf  ) 
    
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    if (i==4) {band <- band/2}
    
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,kernel = "tri",b=band[2],h=band[1])
    
    ptm <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) 
    se <- round(reg$se[3],3) 
    ci <- round(reg$ci[3,],2)
    
    table[1,i*2] <- format(te,nsmall=3, format="f")#paste(format(te,digits=3),stars,sep="")
    table[2,i*2] <- paste("(",format(se,nsmall=3, format="f"),")",sep="")
    table[3,i*2] <- paste("[",format(ci[1],digits=3,nsmall=2),",",format(ci[2],digits=3,nsmall=2),"]",sep="")
    table[4,i*2] <- format(ptm,nsmall=3, format="f")
    table[5,i*2] <- format(round(band[1],1),digits=3)
    table[6,i*2] <- format(round(nrow(subset(bdx, MV <= band[1])),0),nsmall=0)
    
  }
  table2 <- table
  

  print(table1) ; print(table2)
  
  
###################################################################################################################################  
  
###### Table A.XII:  Covariate balance at the discontinuity (Subset 1)  ########################################################### 
  
  vec_cov_names <- c("Mayor's Age","Mayor's Gender","Mayor's Education",
                     "M. Background: Public Sector","M. Background: High-Skilled","Mayor's Party: PT","Mayor's Party: PMDB","Mayor's Party: PSDB",
                     "Mayor's Party: Left","Turnout, 2008","Gini Coefficient, 2000","Per Capita GDP, 2008",
                     "Poverty Rate, 2008","BF Coverage, 2008","SS Employees, 2009","Visits per Family, 2006-08")
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  base_exp$gap <- base_exp$lsa
  qqq <- quantile(prob=.50,base_exp$gap, na.rm=TRUE)
  bdd <- subset(base_exp, !is.na(gap) & base_exp$gap <= qqq)  #> qqq
  #bdd <- subset(bd, !is.na(gap) & bd$gap > qqq)
  
  table <- data.frame(matrix(0,length(vec_cov),11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  #table[c(5,10,15,20),ncol(table)] <- "\tabularnewline[0.2cm]"
  row.names(table) <- vec_cov_names
  
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  table1 <- table 
  
  bdd <- subset(base_exp, !is.na(gap) & base_exp$gap > qqq)  #> qqq
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  table2 <- table 
  
  print(table1)
  print(table2)
  
###################################################################################################################################  
  
###### Table A.XIII:  Covariate balance at the discontinuity (Subset 2)  ########################################################## 
  
   vec_cov_names <- c("Mayor's Age","Mayor's Gender","Mayor's Education",
                     "M. Background: Public Sector","M. Background: High-Skilled","Mayor's Party: PT","Mayor's Party: PMDB","Mayor's Party: PSDB",
                     "Mayor's Party: Left","Turnout, 2008","Gini Coefficient, 2000","Per Capita GDP, 2008",
                     "Poverty Rate, 2008","BF Coverage, 2008","SS Employees, 2009","Visits per Family, 2006-08")
  
  # select only mayoral candidates in the experienced sample
  base_exp <- subset(dat, pref2000 == 1 ) 
  base_exp$gap <- base_exp$h_visits
  qqq <- quantile(prob=.50,base_exp$gap, na.rm=TRUE)
  bdd <- subset(base_exp, !is.na(gap) & base_exp$gap <= qqq)  #> qqq
  #bdd <- subset(bd, !is.na(gap) & bd$gap > qqq)
  
  table <- data.frame(matrix(0,length(vec_cov),11))
  table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
  #table[c(5,10,15,20),ncol(table)] <- "\tabularnewline[0.2cm]"
  row.names(table) <- vec_cov_names
  
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,  b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  table1 <- table 
  
  bdd <- subset(base_exp, !is.na(gap) & base_exp$gap > qqq)  #> qqq
  for (i in 1:length(vec_cov)){
    
    bdd$Var <- bdd[,match(vec_cov[i],names(bdd))]
    pp <- 1 ; qq <- 2
    
    bdx <- subset(bdd, !is.na(Var) & abs(Var) != Inf) 
    band <- rdbwselect(bdx$Var,bdx$run,p=pp,q=qq,bwselect="cerrd")$bws[c(1,3)]
    #band[1] <- 7.5
    
    bdxx <- subset(bdx, MV <= band[1]) 
    reg <- rdrobust(bdx$Var, bdx$run, c = 0, p = pp, q = qq,b=band[2],h=band[1])
    
    pa <- round(reg$tau_cl[1],3)
    te <- round(reg$tau_cl[2]-reg$tau_cl[1],3) ; se <- round(reg$se[3],3) ; ci <- round(reg$ci[3,],2)
    
    stars <- "" #; if(tv >= 1.645*strs){stars <- "*"} ; if(tv >= 1.96*strs){stars <- "**"} 
    table[i,2] <- paste(format(te,nsmall=3),stars,sep="")
    table[i,4] <- paste("(",format(se,nsmall=3),")",sep="")
    table[i,6] <- paste("[",format(ci[1],nsmall=3),",",format(ci[2],nsmall=3),"]",sep="")
    table[i,8] <-  format(round(band[1],1),nsmall=1)
    table[i,10] <- format(round(nrow(bdxx),0),nsmall=0)
    
    #table[nrow(table),i*2] <- nrow(bdx)
    print(i)
  }
  table2 <- table 
  
  print(table1)
  print(table2)
  
###################################################################################################################################  

###### Figure A.I: McCrary test of the manipulation of the running variable ####################################################### 
  
  # select only the treatment group
  library(rdd)
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  DCdensity(base_exp$run, 0, bin = NULL, bw = NULL, verbose = FALSE,
            plot = TRUE, ext.out = FALSE, htest = FALSE)
  
 
###################################################################################################################################  
  
###### Figure A.III: Distribution of the pre-existing BF coverage in the sample (2008), by municipality ########################### 
  
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  bdx <- subset(base_exp, t <= 1 & cov_p2 < 2)
  bdx$cov <- bdx$cov_p2*100
  ggplot(data=bdx, aes(cov)) + 
    theme_bw() +
    geom_density(fill="gray75") + geom_vline(xintercept = 100) +
    ylab("Density") + xlab("Coverage, %") +
    theme(axis.text = element_text(colour="black", size=12)) +
    theme(axis.title = element_text(colour="black", size=12)) 
  
###################################################################################################################################  
  
###### Figure A.IV: Less benefits are approved for eligible families in high-coverage municipalities ############################## 
  
  # select only the treatment group
  base_exp <- subset(dat, pref2000 == 1 ) 
  
  bdx <- subset(base_exp, t <= 1 )
  n <- 12
  bdx$vv <- bdx$yieldbf ; ps <- 0:n/n
  se <- quantile(prob=ps, bdx$vv)
  se[1] <- se[1]-0.0001
  bdx$range <- cut(bdx$vv, se)
  bdx$count <- 1
  bdx$cov <- bdx$BF08/bdx$Target_BF06
  
  agg1 <- aggregate(cov ~ range, data=bdx, mean)
  agg2 <- aggregate(vv     ~ range, data=bdx, median)
  agg3 <- aggregate(count  ~ range, data=bdx, sum)
  
  agg <- merge(agg1,agg2,by="range")
  agg <- merge(agg,agg3,by="range")
  agg <- agg[order(agg$range),]
  
  agg$q <- 1:n

  ggplot(data=agg, aes(x=q, y=cov))   + 
    theme_bw() +
    geom_point(shape=16, size = 3, color = "steelblue2") +
    xlab("Quantile in Past BF Coverage (2008)") + ylab("Share of eligible entries with benefit") +
    theme(axis.text = element_text(colour="black", size=12)) +
    theme(axis.title = element_text(colour="black", size=12)) +
    scale_x_continuous(breaks=c(3,6,9,12),labels=c("25th","50th","75th","99th"))+
    stat_smooth(data=agg, aes(x=q, y=cov), color="gray50", method = "loess", formula = y ~ x  , size = 1)
  
  
###################################################################################################################################  
  
  
  
  
  
  
  
