
library(Matrix)
library(lfe)
dat <- read.table("interview_data.csv", header = TRUE, sep = "," )


###### Table 7:  Loss of benefit when registered by a partisan of the mayor with just eligible income ############################# 

# select only the treatment group
datx <- subset(dat, t == 1 ) 

# set relevant variables
datx$var <- datx$w # partisan of the winner
datx$i <- datx$close10
datx$o <- datx$bf13-datx$bf12
datx$fac1 <- paste(datx$E.Year,datx$q,sep=".")

# set the table formatting
table <- data.frame(matrix(0,7,9))
table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
table[c(nrow(table)-1,nrow(table)),ncol(table)] <- "\tabularnewline[0.2cm]"
row.names(table) <- c("Partisan","S.E.","Just eligible","S.E. ","Partisan x Just eligible","S.E.  ",
                      "Observations")

# run regressions
for (i in 1:4){
  
  if(i==1) reg <- felm(below ~   var +  Foodpc + Water + Income | City+fac1  | 0 | City , data=datx) 
  if(i==2) reg <- felm(close10 ~ var + Foodpc + Water+Income | City+fac1   | 0 | City , data=datx) 
  if(i==3) reg <- felm(o ~ var + i + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) 
  if(i==4) reg <- felm(o ~ var*i  + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) ; summary(reg)
  
  r <- round(summary(reg)$coefficients,3) ; v <- vcov(reg)
  
  coeff <- c("var") 
  if(i==3) coeff <- c("var","i") 
  if(i>3) coeff <- c("var","i","var:i") 
  
  for (j in 0:(length(coeff)-1)){
    tv <- abs(r[row.names(r) == coeff[j+1],3])
    coe <- r[row.names(r) == coeff[j+1],1]
    table[j*2+1,i*2] <- format(coe,nsmall=3)
    table[j*2+2,i*2] <- paste("(",format(r[row.names(r) == coeff[j+1],2],nsmall=3),")",sep="")
  }
  
  if(i==4) {
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]])^.5,3)
    coe <- ( r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1] )         
    tv <- round(abs(coe/sd),3)
    
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+ r[row.names(v) == coeff[1],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[1],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[1]])^.5,3)
    coe <- r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1]   + r[row.names(v) == coeff[1],1]           
    tv <- round(abs(coe/sd),3)
  }
  
  
  table[nrow(table),i*2] <- format(round(nrow(datx),0),nsmall=0)
  table[3:6,c(2,4)] <- ""
  table[5:6,c(6)] <- ""
  
}

# print
table

###################################################################################################################################  


#### Appendix 

###### Table A.XIV: Loss of benefit when registered by a partisan of the opposition with just eligible income ##################### 

# select only the treatment group
datx <- subset(dat, t == 1 ) 

# set relevant variables
datx$var <- datx$l # partisan of the loser
datx$i <- datx$close10
datx$o <- datx$bf13-datx$bf12
datx$fac1 <- paste(datx$E.Year,datx$q,sep=".")

# set the table formatting
table <- data.frame(matrix(0,7,9))
table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
table[c(nrow(table)-1,nrow(table)),ncol(table)] <- "\tabularnewline[0.2cm]"
row.names(table) <- c("Partisan","S.E.","Just eligible","S.E. ","Partisan x Just eligible","S.E.  ",
                      "Observations")

# run regressions
for (i in 1:4){
  
  if(i==1) reg <- felm(below ~   var +  Foodpc + Water + Income | City+fac1  | 0 | City , data=datx) 
  if(i==2) reg <- felm(close10 ~ var + Foodpc + Water+Income | City+fac1   | 0 | City , data=datx) 
  if(i==3) reg <- felm(o ~ var + i + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) 
  if(i==4) reg <- felm(o ~ var*i  + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) ; summary(reg)
  
  r <- round(summary(reg)$coefficients,3) ; v <- vcov(reg)
  
  coeff <- c("var") 
  if(i==3) coeff <- c("var","i") 
  if(i>3) coeff <- c("var","i","var:i") 
  
  for (j in 0:(length(coeff)-1)){
    tv <- abs(r[row.names(r) == coeff[j+1],3])
    coe <- r[row.names(r) == coeff[j+1],1]
    table[j*2+1,i*2] <- format(coe,nsmall=3)
    table[j*2+2,i*2] <- paste("(",format(r[row.names(r) == coeff[j+1],2],nsmall=3),")",sep="")
  }
  
  if(i==4) {
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]])^.5,3)
    coe <- ( r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1] )         
    tv <- round(abs(coe/sd),3)
    
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+ r[row.names(v) == coeff[1],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[1],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[1]])^.5,3)
    coe <- r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1]   + r[row.names(v) == coeff[1],1]           
    tv <- round(abs(coe/sd),3)
  }
  
  
  table[nrow(table),i*2] <- format(round(nrow(datx),0),nsmall=0)
  table[3:6,c(2,4)] <- ""
  table[5:6,c(6)] <- ""
  
}

# print
table

###################################################################################################################################  

###### Table A.XV: Loss of benefit when registered by a partisan of a lame duck mayor with just eligible income ################### 

# select only the control group
datx <- subset(dat, t == 0 ) 

# set relevant variables
datx$var <- datx$w   # partisan of the winner
datx$i <- datx$close10
datx$o <- datx$bf13-datx$bf12
datx$fac1 <- paste(datx$E.Year,datx$q,sep=".")

# set the table formatting
table <- data.frame(matrix(0,7,9))
table[,c(1,3,5,7,9)] <- "&" ; table[,ncol(table)] <- "\tabularnewline" 
table[c(nrow(table)-1,nrow(table)),ncol(table)] <- "\tabularnewline[0.2cm]"
row.names(table) <- c("Partisan","S.E.","Just eligible","S.E. ","Partisan x Just eligible","S.E.  ",
                      "Observations")

# run regressions
for (i in 1:4){
  
  if(i==1) reg <- felm(below ~   var +  Foodpc + Water + Income | City+fac1  | 0 | City , data=datx) 
  if(i==2) reg <- felm(close10 ~ var + Foodpc + Water+Income | City+fac1   | 0 | City , data=datx) 
  if(i==3) reg <- felm(o ~ var + i + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) 
  if(i==4) reg <- felm(o ~ var*i  + Foodpc + Water+Income  | City+fac1   | 0 | City , data=datx) ; summary(reg)
  
  r <- round(summary(reg)$coefficients,3) ; v <- vcov(reg)
  
  coeff <- c("var") 
  if(i==3) coeff <- c("var","i") 
  if(i>3) coeff <- c("var","i","var:i") 
  
  for (j in 0:(length(coeff)-1)){
    tv <- abs(r[row.names(r) == coeff[j+1],3])
    coe <- r[row.names(r) == coeff[j+1],1]
    table[j*2+1,i*2] <- format(coe,nsmall=3)
    table[j*2+2,i*2] <- paste("(",format(r[row.names(r) == coeff[j+1],2],nsmall=3),")",sep="")
  }
  
  if(i==4) {
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]])^.5,3)
    coe <- ( r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1] )         
    tv <- round(abs(coe/sd),3)
    
    sd <- round((r[row.names(v) == coeff[2],2]**2+
                   r[row.names(v) == coeff[3],2]**2+ r[row.names(v) == coeff[1],2]**2+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[1],colnames(v) == coeff[3]]+
                   2*v[rownames(v) == coeff[2],colnames(v) == coeff[1]])^.5,3)
    coe <- r[row.names(v) == coeff[2],1] + r[row.names(v) == coeff[3],1]   + r[row.names(v) == coeff[1],1]           
    tv <- round(abs(coe/sd),3)
  }
  
  
  table[nrow(table),i*2] <- format(round(nrow(datx),0),nsmall=0)
  table[3:6,c(2,4)] <- ""
  table[5:6,c(6)] <- ""
  
}

# print
table

###################################################################################################################################  



