

library(ggplot2) 
dat <- read.table("plot_data.csv", header = TRUE, sep = "," )


###### Figure 1: Global coverage of the BF program  #############################################################################


#### The number of total BF beneficiaries in Brazil was a manual input from the MDS website
bf <- c(4103013,6571839,7031669,8700445,11166924,10965810,10749655,11043076,11075201,10557996,
        11611680,12370915,12649019,12778220,12999560,13361495,13462659,13902155)
period <- c("1S04","2S04","1S05","2S05","1S06","2S06","1S07","2S07","1S08","2S08","1S09","2S09",
            "1S10","2S10","1S11","2S11","1S12","2S12")
plotty <- data.frame(bf,period)
plotty$n <- 1:18

### Coverage targets were also entered manually
plotty$target <- 11100000
plotty$target[11:15] <- 12995195
plotty$target[16:18] <- 13737202

plotty$cov <- plotty$bf*100/plotty$target
plotty$bf2 <- plotty$bf/1000000
plotty$cov2 <- plotty$cov/7.28 ; plotty
plotty$secy <- plotty$bf2/13.73

ggplot(data=plotty, aes(x=n,y=bf2,group=1)) + 
  #ylim(0,120)+
  theme_bw() +
  geom_line(aes(y = bf2, color = "Benefits"), size=.75) +  geom_point(aes(y = bf2, color = "Benefits"))  +
  scale_x_continuous(breaks=c(2,6,10,14,18), labels=c("2004","2006","2008","2010","2012")) +
  ylab("Number of Benefits, mn") +
  theme(axis.text = element_text(colour="black", size=12)) +
  theme(legend.title = element_text(colour="black", size=12)) +
  theme(legend.text = element_text(colour="black", size=12)) +
  theme(axis.title = element_text(colour="black", size=12)) +
  theme(axis.title.x = element_blank()) +
  geom_line(aes(y = cov2, color = "Global Coverage"), size=1.5, alpha=0.5) +
  scale_y_continuous(sec.axis = sec_axis(~./0.1373, name = "Global coverage, %")) +
  theme(legend.position = "bottom") +
  scale_color_manual(values = c("gray25", "steelblue2")) + labs(colour = "Variable")




###################################################################################################################################

###### Figure 5: Share of households receiving BF benefits, by declared income  ################################################### 

#### aggregate income declaration in R$10 intervals
dat$X <- 1:60
dat$g <- ceiling(dat$X/2)
dat$wbf12 <- dat$bf12*dat$c

agg1 <- aggregate(wbf12 ~ g, data=dat, sum)
agg2 <- aggregate(c ~ g, data=dat, sum)
agg <- merge(agg1,agg2,by="g")
agg$bf12 <- agg$wbf12/agg$c

agg$gg <- "eligible"
agg$gg[15:30] <- "non-eligible"

se <- (1:30)*10
agg$x <- se

#### print
ggplot(agg, aes(x=x,y=bf12,fill=gg)) +theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  xlab("Declared Income, R$/month") + ylab("Share with Benefit in 2012") +
  geom_bar(stat="identity", position=position_dodge(), width=7) +
  scale_x_continuous(breaks = c(20,60,100,140,180,220,260,300)) +
  theme(axis.text = element_text(colour="black", size=12)) +
  theme(axis.title = element_text(colour="black", size=12)) +
  scale_fill_manual(values=c("gray75","gray35"), name="Status")+
  theme(legend.position=c(.7,.8))



###################################################################################################################################

###### Figure 6:  Loss of benefit post-audit, by level of declared income  ######################################################## 

#### limit reported income to R$140 (the BF eligibility level)
n <- 28

### redefine dataframe
datx <- dat[1:n,]

### set labels for x-axis
se <- (1:28)*5 ; datx$x <- se

### plot
ggplot(datx, aes(x=x,y=loss)) +theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  xlab("Declared Income, R$/month") + ylab("Loss in benefits in 2013, %") +
  geom_point(pch=21) +
  stat_smooth(method="loess",color="gray25",formula=y~x) +
  scale_x_continuous(breaks = c(20,40,60,80,100,120,140)) +
  theme(axis.text = element_text(colour="black", size=12)) +
  theme(axis.title = element_text(colour="black", size=12)) +
  scale_fill_manual(values=c("gray75","gray35"), name="Status")+
  theme(legend.position=c("none"))


###################################################################################################################################

###### Figure A.II: Distribution of the reported income: CadUnico vs. Census ###################################################### 

# select only the treatment group

dat$g <- 1
dat$g[8:14] <- 2
dat$g[15:21] <- 3
dat$g[22:28] <- 4
dat$g[29:35] <- 5
dat$g[36:42] <- 6
dat$g[43:49] <- 7
dat$g[50:56] <- 8
dat$g[57:60] <- 9

agg1 <- aggregate(c~g, data=dat, sum) ; agg1$t <- "CadUnico"
agg2 <- aggregate(Weight~g, data=dat, sum) ; agg2$t <- "Census"
agg1$density <- agg1$c / sum(agg1$c)
agg2$density <- agg2$Weight / sum(agg2$Weight)
agg1$c <- NULL
agg2$Weight <- NULL

vec <- c(35,70,105,140,175,210,245,280,315)

plot <- rbind(agg1[1:9,],agg2[1:9,])
plot$x <- c(vec,vec)
plot <- data.frame(plot)

ggplot(plot, aes(x=x,y=density,fill=t)) +theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  geom_bar(stat="identity", position=position_dodge(), width=30) +
  xlab("Income, R$/month") +
  theme(axis.text = element_text(colour="black", size=12)) +
  theme(axis.title = element_text(colour="black", size=12)) +
  scale_x_continuous(breaks=c(0,70,140,210,280)) +
  scale_fill_manual(values=c("gray75","gray35"), name="Source")+
  theme(legend.position=c(.5,.75))




###################################################################################################################################  

